package sun.security.provider;

import java.security.AccessController;
import java.security.Security;
import java.security.PrivilegedAction;
import sun.security.action.GetPropertyAction;
import java.io.IOException;
import java.net.URISyntaxException;
import java.net.URI;
import java.io.File;
import java.net.URL;
import java.util.Iterator;
import java.util.HashMap;
import java.util.Arrays;
import java.util.List;
import java.security.Provider;
import java.util.LinkedHashSet;

public final class SunEntries
{
    public static final String DEF_SECURE_RANDOM_ALGO;
    private LinkedHashSet<Provider.Service> services;
    private static final String PROP_EGD = "java.security.egd";
    private static final String PROP_RNDSOURCE = "securerandom.source";
    private static final boolean useLegacyDSA;
    static final String URL_DEV_RANDOM = "file:/dev/random";
    static final String URL_DEV_URANDOM = "file:/dev/urandom";
    private static final String seedSource;
    
    public static List<String> createAliases(String... a) {
        return Arrays.asList(a);
    }
    
    public static List<String> createAliasesWithOid(String... original) {
        String[] a = (String[])Arrays.copyOf(original, original.length + 1);
        a[a.length - 1] = "OID." + original[0];
        return Arrays.asList(a);
    }
    
    SunEntries(Provider provider) {
        this.services = new LinkedHashSet(50, 0.9f);
        HashMap hashMap = new HashMap(3);
        hashMap.put("ThreadSafe", "true");
        if (NativePRNG.isAvailable()) {
            this.add(provider, "SecureRandom", "NativePRNG", "sun.security.provider.NativePRNG", null, hashMap);
        }
        if (NativePRNG.Blocking.isAvailable()) {
            this.add(provider, "SecureRandom", "NativePRNGBlocking", "sun.security.provider.NativePRNG$Blocking", null, hashMap);
        }
        if (NativePRNG.NonBlocking.isAvailable()) {
            this.add(provider, "SecureRandom", "NativePRNGNonBlocking", "sun.security.provider.NativePRNG$NonBlocking", null, hashMap);
        }
        hashMap.put("ImplementedIn", "Software");
        this.add(provider, "SecureRandom", "SHA1PRNG", "sun.security.provider.SecureRandom", null, hashMap);
        hashMap.clear();
        hashMap.put("SupportedKeyClasses", "java.security.interfaces.DSAPublicKey|java.security.interfaces.DSAPrivateKey");
        hashMap.put("ImplementedIn", "Software");
        hashMap.put("KeySize", "1024");
        this.add(provider, "Signature", "SHA1withDSA", "sun.security.provider.DSA$SHA1withDSA", createAliasesWithOid(new String[] { "1.2.840.10040.4.3", "DSA", "DSS", "SHA/DSA", "SHA-1/DSA", "SHA1/DSA", "SHAwithDSA", "DSAWithSHA1", "1.3.14.3.2.13", "1.3.14.3.2.27" }), hashMap);
        this.add(provider, "Signature", "NONEwithDSA", "sun.security.provider.DSA$RawDSA", createAliases(new String[] { "RawDSA" }), hashMap);
        hashMap.put("KeySize", "2048");
        this.add(provider, "Signature", "SHA224withDSA", "sun.security.provider.DSA$SHA224withDSA", createAliasesWithOid(new String[] { "2.16.840.1.101.3.4.3.1" }), hashMap);
        this.add(provider, "Signature", "SHA256withDSA", "sun.security.provider.DSA$SHA256withDSA", createAliasesWithOid(new String[] { "2.16.840.1.101.3.4.3.2" }), hashMap);
        hashMap.clear();
        hashMap.put("ImplementedIn", "Software");
        hashMap.put("KeySize", "2048");
        List<String> aliasesWithOid = createAliasesWithOid(new String[] { "1.2.840.10040.4.1", "1.3.14.3.2.12" });
        this.add(provider, "KeyPairGenerator", "DSA", "sun.security.provider.DSAKeyPairGenerator$" + (SunEntries.useLegacyDSA ? "Legacy" : "Current"), aliasesWithOid, hashMap);
        this.add(provider, "AlgorithmParameterGenerator", "DSA", "sun.security.provider.DSAParameterGenerator", aliasesWithOid, hashMap);
        hashMap.remove("KeySize");
        this.add(provider, "AlgorithmParameters", "DSA", "sun.security.provider.DSAParameters", aliasesWithOid, hashMap);
        this.add(provider, "KeyFactory", "DSA", "sun.security.provider.DSAKeyFactory", aliasesWithOid, hashMap);
        this.add(provider, "MessageDigest", "MD2", "sun.security.provider.MD2", null, hashMap);
        this.add(provider, "MessageDigest", "MD5", "sun.security.provider.MD5", null, hashMap);
        this.add(provider, "MessageDigest", "SHA", "sun.security.provider.SHA", createAliasesWithOid(new String[] { "1.3.14.3.2.26", "SHA-1", "SHA1" }), hashMap);
        String s = "2.16.840.1.101.3.4.2";
        this.add(provider, "MessageDigest", "SHA-224", "sun.security.provider.SHA2$SHA224", createAliasesWithOid(new String[] { s + ".4" }), hashMap);
        this.add(provider, "MessageDigest", "SHA-256", "sun.security.provider.SHA2$SHA256", createAliasesWithOid(new String[] { s + ".1" }), hashMap);
        this.add(provider, "MessageDigest", "SHA-384", "sun.security.provider.SHA5$SHA384", createAliasesWithOid(new String[] { s + ".2" }), hashMap);
        this.add(provider, "MessageDigest", "SHA-512", "sun.security.provider.SHA5$SHA512", createAliasesWithOid(new String[] { s + ".3" }), hashMap);
        this.add(provider, "MessageDigest", "SHA-512/224", "sun.security.provider.SHA5$SHA512_224", createAliasesWithOid(new String[] { s + ".5" }), hashMap);
        this.add(provider, "MessageDigest", "SHA-512/256", "sun.security.provider.SHA5$SHA512_256", createAliasesWithOid(new String[] { s + ".6" }), hashMap);
        this.add(provider, "CertificateFactory", "X.509", "sun.security.provider.X509Factory", createAliases(new String[] { "X509" }), hashMap);
        this.add(provider, "KeyStore", "JKS", "sun.security.provider.JavaKeyStore$DualFormatJKS", null, hashMap);
        this.add(provider, "KeyStore", "CaseExactJKS", "sun.security.provider.JavaKeyStore$CaseExactJKS", null, hashMap);
        this.add(provider, "KeyStore", "DKS", "sun.security.provider.DomainKeyStore$DKS", null, hashMap);
        hashMap.clear();
        hashMap.put("LDAPSchema", "RFC2587");
        hashMap.put("ImplementedIn", "Software");
        this.add(provider, "CertStore", "LDAP", "sun.security.provider.certpath.ldap.LDAPCertStore", null, hashMap);
        hashMap.remove("LDAPSchema");
        this.add(provider, "CertStore", "Collection", "sun.security.provider.certpath.CollectionCertStore", null, hashMap);
        this.add(provider, "CertStore", "com.sun.security.IndexedCollection", "sun.security.provider.certpath.IndexedCollectionCertStore", null, hashMap);
        this.add(provider, "Policy", "JavaPolicy", "sun.security.provider.PolicySpiFile", null, null);
        this.add(provider, "Configuration", "JavaLoginConfig", "sun.security.provider.ConfigFile$Spi", null, null);
        hashMap.clear();
        hashMap.put("ValidationAlgorithm", "RFC5280");
        hashMap.put("ImplementedIn", "Software");
        this.add(provider, "CertPathBuilder", "PKIX", "sun.security.provider.certpath.SunCertPathBuilder", null, hashMap);
        this.add(provider, "CertPathValidator", "PKIX", "sun.security.provider.certpath.PKIXCertPathValidator", null, hashMap);
    }
    
    Iterator<Provider.Service> iterator() {
        return this.services.iterator();
    }
    
    private void add(Provider provider, String type, String algorithm, String className, List<String> aliases, HashMap<String, String> attributes) {
        this.services.add(new Provider.Service(provider, type, algorithm, className, aliases, attributes));
    }
    
    static String getSeedSource() {
        return SunEntries.seedSource;
    }
    
    static File getDeviceFile(URL url) throws IOException {
        try {
            URI uri = url.toURI();
            if (uri.isOpaque()) {
                return new File(URI.create(new File(System.getProperty("user.dir")).toURI().toString() + uri.toString().substring(5)));
            }
            return new File(uri);
        }
        catch (URISyntaxException ex) {
            return new File(url.getPath());
        }
    }
    
    static {
        useLegacyDSA = Boolean.parseBoolean(GetPropertyAction.privilegedGetProperty("jdk.security.legacyDSAKeyPairGenerator"));
        seedSource = (String)AccessController.doPrivileged(new PrivilegedAction<String>() {
            @Override
            public String run() {
                String property = System.getProperty("java.security.egd", "");
                if (property.length() != 0) {
                    return property;
                }
                String property2 = Security.getProperty("securerandom.source");
                if (property2 == null) {
                    return "";
                }
                return property2;
            }
        });
        DEF_SECURE_RANDOM_ALGO = ((NativePRNG.isAvailable() && (SunEntries.seedSource.equals("file:/dev/urandom") || SunEntries.seedSource.equals("file:/dev/random"))) ? "NativePRNG" : "SHA1PRNG");
    }
}
